@@ -15,6 +15,7 @@
 # specific language governing permissions and limitations
 # under the License.
 import datetime
+import logging
 import os
 import shutil
 from abc import ABC
@@ -22,6 +23,7 @@ from tempfile import NamedTemporaryFile
 from typing import Dict, Text, List, Optional
 
 import cloudpickle
+from airflow.exceptions import DagNotFound
 
 from ai_flow_plugins.scheduler_plugins.airflow.dag_generator import DAGGenerator
 from ai_flow.context.project_context import ProjectContext
@@ -39,23 +41,28 @@ from airflow.utils.db import create_session
 from airflow.utils.state import State
 from airflow.contrib.jobs.scheduler_client import EventSchedulerClient, SCHEDULER_NAMESPACE, ExecutionContext
 from airflow.utils.dates import parse_execution_date
+from airflow.api.common.experimental import delete_dag
+
+logger = logging.getLogger(__name__)
 
 
 class AirFlowSchedulerBase(Scheduler, ABC):
     """
     AirFlowScheduler is an implementation of a Scheduler interface based on AirFlow.
     AirFlowScheduler contains two configuration items:
-    1. notification_service_uri: The address of NotificationService.
+    1. notification_server_uri: The address of NotificationService.
     2. airflow_deploy_path: AirFlow dag file deployment directory.
     """
 
     def __init__(self, config: Dict):
-        if 'notification_service_uri' not in config:
-            raise Exception('`notification_service_uri` option of scheduler config is not configured. '
-                            'Please add the `notification_service_uri` option under `scheduler_config` option!')
+        if 'notification_server_uri' not in config:
+            raise Exception('`notification_server_uri` option of scheduler config is not configured. '
+                            'Please add the `notification_server_uri` option under `scheduler_config` option!')
         if 'airflow_deploy_path' not in config:
-            raise Exception('`airflow_deploy_path` option of scheduler config is not configured. '
-                            'Please add the `notification_service_uri` option under `scheduler_config` option!')
+            from airflow import settings
+            dags_folder = settings.DAGS_FOLDER
+            config['airflow_deploy_path'] = dags_folder
+            logger.info("airflow_deploy_path is set to {} from airflow config".format(dags_folder))
         super().__init__(config)
         self.dag_generator = DAGGenerator()
         self._airflow_client = None
@@ -101,8 +108,9 @@ class AirFlowSchedulerBase(Scheduler, ABC):
     @property
     def airflow_client(self):
         if self._airflow_client is None:
-            self._airflow_client = EventSchedulerClient(server_uri=self.config.get('notification_service_uri'),
-                                                        namespace=SCHEDULER_NAMESPACE)
+            self._airflow_client = EventSchedulerClient(
+                notification_server_uri=self.config.get('notification_server_uri'),
+                namespace=SCHEDULER_NAMESPACE)
         return self._airflow_client
 
     def submit_workflow(self, workflow: Workflow, context_extractor, project_context: ProjectContext) -> WorkflowInfo:
@@ -138,6 +146,16 @@ class AirFlowSchedulerBase(Scheduler, ABC):
         deploy_path = self.config.get('airflow_deploy_path')
         if deploy_path is None:
             raise Exception("airflow_deploy_path config not set!")
+
+        self.pause_workflow_scheduling(project_name=project_name,
+                                       workflow_name=workflow_name)
+        self.stop_all_workflow_execution(project_name=project_name,
+                                         workflow_name=workflow_name)
+        try:
+            delete_dag.delete_dag(dag_id)
+        except DagNotFound:
+            raise Exception("DAG with id {} not found. Cannot delete".format(dag_id))
+
         airflow_file_path = os.path.join(deploy_path,
                                          dag_id + '.py')
         if os.path.exists(airflow_file_path):
@@ -153,7 +171,7 @@ class AirFlowScheduler(AirFlowSchedulerBase):
     """
     AirFlowScheduler is an implementation of a Scheduler interface based on AirFlow.
     AirFlowScheduler contains two configuration items:
-    1. notification_service_uri: The address of NotificationService.
+    1. notification_server_uri: The address of server of NotificationService.
     2. airflow_deploy_path: AirFlow dag file deployment directory.
     """
 
