@@ -337,6 +337,14 @@ def webserver(args):
     worker_timeout = args.worker_timeout or conf.get('webserver', 'web_server_worker_timeout')
     ssl_cert = args.ssl_cert or conf.get('webserver', 'web_server_ssl_cert')
     ssl_key = args.ssl_key or conf.get('webserver', 'web_server_ssl_key')
+    notification_server_uri = args.notification_server_uri or conf.get('scheduler', 'notification_server_uri',
+                                                                       fallback='127.0.0.1:50052')
+    notification_sql_alchemy_conn = args.notification_sql_alchemy_conn \
+                                    or conf.get('webserver',
+                                                'notification_sql_alchemy_conn',
+                                                fallback='sqlite:///{}/notification_service/ns.db'.format(
+                                                    os.environ['HOME']))
+
     if not ssl_cert and ssl_key:
         raise AirflowException('An SSL certificate must also be provided for use with ' + ssl_key)
     if ssl_cert and not ssl_key:
@@ -344,7 +352,9 @@ def webserver(args):
 
     if args.debug:
         print(f"Starting the web server on port {args.port} and host {args.hostname}.")
-        app = create_app(testing=conf.getboolean('core', 'unit_test_mode'), server_uri=args.server_uri)
+        app = create_app(testing=conf.getboolean('core', 'unit_test_mode'),
+                         notification_server_uri=notification_server_uri,
+                         notification_sql_alchemy_conn=notification_sql_alchemy_conn)
         app.run(
             debug=True,
             use_reloader=not app.config['TESTING'],
@@ -422,7 +432,8 @@ def webserver(args):
         if ssl_cert:
             run_args += ['--certfile', ssl_cert, '--keyfile', ssl_key]
 
-        run_args += ["airflow.www.app:cached_app()"]
+        run_args += ["airflow.www.app:cached_app(notification_server_uri='{}', notification_sql_alchemy_conn='{}')"
+                     .format(notification_server_uri, notification_sql_alchemy_conn)]
 
         gunicorn_master_proc = None
 
@@ -452,8 +463,6 @@ def webserver(args):
                 ),
             ).start()
 
-        os.environ['SERVER_URI'] = args.server_uri
-
         if args.daemon:
             handle = setup_logging(log_file)
 
@@ -466,7 +475,7 @@ def webserver(args):
                     stderr=stderr,
                 )
                 with ctx:
-                    subprocess.Popen(run_args, close_fds=True, env=os.environ)
+                    subprocess.Popen(run_args, close_fds=True)
 
                     # Reading pid of gunicorn master as it will be different that
                     # the one of process spawned above.
@@ -481,5 +490,5 @@ def webserver(args):
                     monitor_gunicorn(gunicorn_master_proc.pid)
 
         else:
-            gunicorn_master_proc = subprocess.Popen(run_args, close_fds=True, env=os.environ)
+            gunicorn_master_proc = subprocess.Popen(run_args, close_fds=True)
             monitor_gunicorn(gunicorn_master_proc.pid)
