@@ -77,7 +77,7 @@ class EventBasedScheduler(LoggingMixin):
                  task_event_manager: DagRunEventManager,
                  executor: BaseExecutor,
                  notification_client: NotificationClient,
-                 server_uri: str,
+                 notification_server_uri: str,
                  context=None,
                  periodic_manager: PeriodicManager = None):
         super().__init__(context)
@@ -90,7 +90,7 @@ class EventBasedScheduler(LoggingMixin):
         self._timer_handler = None
         self.timers = sched.scheduler()
         self.periodic_manager = periodic_manager
-        self.server_uri = server_uri
+        self.notification_server_uri = notification_server_uri
 
     def sync(self):
 
@@ -164,23 +164,30 @@ class EventBasedScheduler(LoggingMixin):
                     self.log.warning("dagrun is None for dag_id:{} execution_date: {}".format(
                         event.dag_id, event.execution_date))
             elif isinstance(event, DagExecutableEvent):
-                dagrun = self._create_dag_run(event.dag_id, session=session)
-                tasks = self._find_scheduled_tasks(dagrun, session)
-                self._send_scheduling_task_events(tasks, SchedulingAction.START)
+                if DagModel.dag_needing_dagruns(session, event.dag_id):
+                    dagrun = self._create_dag_run(event.dag_id, session=session)
+                    tasks = self._find_scheduled_tasks(dagrun, session)
+                    self._send_scheduling_task_events(tasks, SchedulingAction.START)
             elif isinstance(event, EventHandleEvent):
                 dag_runs = DagRun.find(dag_id=event.dag_id, run_id=event.dag_run_id)
-                assert len(dag_runs) == 1
-                ti = dag_runs[0].get_task_instance(event.task_id)
-                self._send_scheduling_task_event(ti, event.action)
+                if len(dag_runs) < 1:
+                    self.log.warning("DagRun not found by dag_id:{}, run_id:{}".format(
+                        event.dag_id, event.dag_run_id))
+                else:
+                    ti = dag_runs[0].get_task_instance(event.task_id)
+                    self._send_scheduling_task_event(ti, event.action)
             elif isinstance(event, StopDagEvent):
                 self._stop_dag(event.dag_id, session)
             elif isinstance(event, DagRunFinishedEvent):
                 self._remove_periodic_events(event.dag_id, event.execution_date)
             elif isinstance(event, PeriodicEvent):
                 dag_runs = DagRun.find(dag_id=event.dag_id, execution_date=event.execution_date)
-                assert len(dag_runs) == 1
-                ti = dag_runs[0].get_task_instance(event.task_id)
-                self._send_scheduling_task_event(ti, SchedulingAction.RESTART)
+                if len(dag_runs) < 1:
+                    self.log.warning("DagRun not found by dag_id:{}, execution_date:{}".format(
+                        event.dag_id, event.execution_date))
+                else:
+                    ti = dag_runs[0].get_task_instance(event.task_id)
+                    self._send_scheduling_task_event(ti, SchedulingAction.RESTART)
             elif isinstance(event, StopSchedulerEvent):
                 self.log.info("{} {}".format(self.id, event.job_id))
                 if self.id == event.job_id or 0 == event.job_id:
@@ -622,13 +629,15 @@ class EventBasedSchedulerJob(BaseJob):
     __mapper_args__ = {'polymorphic_identity': 'EventBasedSchedulerJob'}
 
     def __init__(self, dag_directory,
-                 server_uri=None,
+                 notification_server_uri=None,
                  event_start_time=None,
                  max_runs=-1,
                  refresh_dag_dir_interval=conf.getint('scheduler', 'refresh_dag_dir_interval', fallback=1),
                  *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.log.info("Starting event based scheduler with notification server uri: {}".format(server_uri))
+        if notification_server_uri is None:
+            notification_server_uri = conf.get('scheduler', 'notification_server_uri', fallback='127.0.0.1:50052')
+        self.log.info("Starting event based scheduler with notification server uri: {}".format(notification_server_uri))
         self.mailbox: Mailbox = Mailbox()
         self.dag_trigger: DagTrigger = DagTrigger(
             dag_directory=dag_directory,
@@ -637,12 +646,12 @@ class EventBasedSchedulerJob(BaseJob):
             pickle_dags=False,
             mailbox=self.mailbox,
             refresh_dag_dir_interval=refresh_dag_dir_interval,
-            notification_service_uri=server_uri
+            notification_server_uri=notification_server_uri
         )
         self.task_event_manager = DagRunEventManager(self.mailbox)
         self.executor.set_mailbox(self.mailbox)
-        self.executor.set_server_uri(server_uri)
-        self.notification_client: NotificationClient = NotificationClient(server_uri=server_uri,
+        self.executor.set_notification_server_uri(notification_server_uri)
+        self.notification_client: NotificationClient = NotificationClient(server_uri=notification_server_uri,
                                                                           default_namespace=SCHEDULER_NAMESPACE)
         self.periodic_manager = PeriodicManager(self.mailbox)
         self.scheduler: EventBasedScheduler = EventBasedScheduler(
@@ -651,7 +660,7 @@ class EventBasedSchedulerJob(BaseJob):
             self.task_event_manager,
             self.executor,
             self.notification_client,
-            server_uri,
+            notification_server_uri,
             None,
             self.periodic_manager
         )
