@@ -28,6 +28,7 @@ import operator
 import os
 import subprocess
 import time
+import copy
 import traceback
 from collections import OrderedDict
 from multiprocessing import Pool, cpu_count
@@ -423,10 +424,11 @@ class CeleryExecutor(BaseExecutor):
     def update_all_task_states(self) -> None:
         """Updates states of the tasks."""
         self.log.debug("Inquiring about %s celery task(s)", len(self.tasks))
-        state_and_info_by_celery_task_id = self.bulk_state_fetcher.get_many(self.tasks.values())
+        tasks_copy = copy.deepcopy(self.tasks)
+        state_and_info_by_celery_task_id = self.bulk_state_fetcher.get_many(tasks_copy.values())
 
         self.log.debug("Inquiries completed.")
-        for key, async_result in list(self.tasks.items()):
+        for key, async_result in list(tasks_copy.items()):
             state, info = state_and_info_by_celery_task_id.get(async_result.task_id)
             if state:
                 self.update_task_state(key, state, info)
