@@ -18,28 +18,19 @@
 ## under the License.
 ##
 set -e
-usage="Usage: start-all-aiflow-services.sh [aiflow-mysql-conn]"
+BIN=$(dirname "${BASH_SOURCE-$0}")
+BIN=$(cd "$BIN"; pwd)
 
-if [ $# -ne 1 ]; then
-  echo $usage
-  exit 1
-fi
+# start notification service
+"${BIN}"/start-notification.sh
+echo "start notification server."
+sleep 3
 
-export AIFLOW_DB_CONN=$1
-export AIFLOW_DB_TYPE="MYSQL"
-
-BIN=`dirname "${BASH_SOURCE-$0}"`
-BIN=`cd "$BIN"; pwd`
-
-# init aiflow env
-. ${BIN}/init-aiflow-env.sh
-${BIN}/init-airflow-env.sh ${AIFLOW_DB_CONN}
+# start airflow scheduler and web server
+"${BIN}"/start-airflow.sh
+echo "airflow dag dir: ${AIRFLOW_DAG_DIR}"
 
 # start AIFlow
-${BIN}/start-aiflow.sh
-# Wait for notification service to reach the running state
-sleep 5
-# start airflow scheduler and web server
-${BIN}/start-airflow.sh ${AIFLOW_DB_CONN}
+"${BIN}"/start-aiflow.sh
 
-echo "Visit http://127.0.0.1:8080/ to access the airflow web server."
+echo "All services have been started!"
