@@ -19,29 +19,24 @@
 ##
 set -e
 
-BIN=`dirname "${BASH_SOURCE-$0}"`
-BIN=`cd "$BIN"; pwd`
-. ${BIN}/init-aiflow-env.sh
+AIFLOW_HOME=${AIFLOW_HOME:-~/aiflow}
+AIFLOW_PID_DIR=${AIFLOW_PID_DIR:-${AIFLOW_HOME}}
 
-if [ ! -e ${AIFLOW_PID_DIR}/aiflow_server.pid ]; then
-  echo "No aiflow server running"
-fi
+kill_with_pid_file() {
+  if [ ! -e "$2" ]; then
+    echo "No $1 running"
+  else
+    echo "Stopping $1"
+    for ((i=1;i<=3;i++))
+    do
+      kill $(cat "$2") >/dev/null 2>&1 && sleep 1
+    done
+
+    rm "$2" 2>/dev/null
+    echo "$1 stopped"
+  fi
+}
 
 set +e
-echo "Killing AIFlow Server"
-for ((i=1;i<=3;i++))
-do
-  kill $(cat ${AIFLOW_PID_DIR}/aiflow_server.pid) >/dev/null 2>&1 && sleep 1
-done
-
-rm ${AIFLOW_PID_DIR}/aiflow_server.pid
-echo "AIFlow Server killed"
-
-echo "Killing AIFlow Web"
-for ((i=1;i<=3;i++))
-do
-  kill $(cat ${AIFLOW_PID_DIR}/aiflow_web_server.pid) >/dev/null 2>&1 && sleep 1
-done
-
-rm ${AIFLOW_PID_DIR}/aiflow_web_server.pid
-echo "AIFlow Web killed"
+kill_with_pid_file "AIFlow Server" "${AIFLOW_PID_DIR}"/aiflow_server.pid
+kill_with_pid_file "AIFlow Web Server" "${AIFLOW_PID_DIR}"/aiflow_web_server.pid
