@@ -19,26 +19,27 @@
 ##
 set -e
 
-BIN=`dirname "${BASH_SOURCE-$0}"`
-BIN=`cd "$BIN"; pwd`
-. ${BIN}/init-aiflow-env.sh
+BIN=$(dirname "${BASH_SOURCE-$0}")
+BIN=$(cd "$BIN"; pwd)
+export AIRFLOW_HOME=${AIRFLOW_HOME:-~/airflow}
+export AIRFLOW_SCHEDULER_PID_FILE="${AIRFLOW_HOME}/scheduler.pid"
+export AIRFLOW_WEB_PID_FILE="${AIRFLOW_HOME}/web.pid"
 
-if [ ! -e ${AIFLOW_PID_DIR}/scheduler.pid ]; then
-  echo "No airflow scheduler running"
-fi
+kill_with_pid_file() {
+  if [ ! -e "$2" ]; then
+    echo "No $1 running"
+  else
+    echo "Stopping $1"
+    for ((i=1;i<=3;i++))
+    do
+      kill $(cat "$2") >/dev/null 2>&1 && sleep 1
+    done
 
-if [ ! -e ${AIFLOW_PID_DIR}/web.pid ]; then
-  echo "No airflow web server running"
-fi
+    rm "$2" 2>/dev/null
+    echo "$1 stopped"
+  fi
+}
 
 set +e
-echo "Killing Airflow scheduler and web server"
-for ((i=1;i<=3;i++))
-do
-  kill $(cat ${AIFLOW_PID_DIR}/scheduler.pid) >/dev/null 2>&1 && sleep 1
-  kill $(cat ${AIFLOW_PID_DIR}/web.pid) >/dev/null 2>&1 && sleep 1
-done
-
-rm ${AIFLOW_PID_DIR}/scheduler.pid
-rm ${AIFLOW_PID_DIR}/web.pid
-echo "Airflow scheduler and web server killed"
+kill_with_pid_file "airflow scheduler" "${AIRFLOW_SCHEDULER_PID_FILE}"
+kill_with_pid_file "airflow web server" "${AIRFLOW_WEB_PID_FILE}"
